@@ -1,8 +1,9 @@
 
 import argparse
+import subprocess
 
 from notebuild.shell import run_shell, run_shell_list
-from notejob.run.core import start
+from notejob.tasks import start
 from notetool.tool.log import log
 
 logger = log("notebuild")
@@ -19,6 +20,15 @@ class JobScheduler:
     def stop(self):
         logger.info("stop")
 
+        port = subprocess.check_output("ps x | grep notejob", shell=True)
+
+        for line in port.decode().strip('\n').split('\n'):
+            a = [i for i in line.split(' ') if len(i) > 0]
+
+            if 'notejob' in a[-2] and (a[-1] == 'start' or a[-1] == 'restart'):
+                subprocess.check_output('kill -9 {}'.format(a[0]), shell=True)
+                logger.info("kill zhe process \n{}\n".format(line))
+
     def restart(self):
         self.stop()
         self.start()
